<?php

class AmadeoWidgetImage extends WP_Widget{

	public function __construct(){
		$widget_ops = array(
			'classname'		=> 'amadeo_widget_image',
			'description'	=> esc_html__('Add image with link', 'amadeo-free'),
		);

		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('amadeo_widget_image', esc_html__('Image with link', 'amadeo-free'), $widget_ops, $control_ops);
		
		add_action('admin_enqueue_scripts',						array($this, 'amadeoAddAdminScripts'));
		add_action('wp_ajax_amadeoImageWidgetAJAX',			array($this, 'amadeoImageWidgetAJAX'));
		add_action('wp_ajax_nopriv_amadeoImageWidgetAJAX',	array($this, 'amadeoImageWidgetAJAX'));
	}
	
	function amadeoAddAdminScripts(){
		if(get_current_screen()->id == 'widgets' || get_current_screen()->id == 'customize'){
			
			wp_enqueue_script('jquery');
			wp_enqueue_media();
			
			wp_register_style('amadeo_wi_admin_css', $this->amadeoPluginDirUrl() . '/css/amadeo-widget-image.css');
			wp_enqueue_style('amadeo_wi_admin_css');
			
			wp_enqueue_script('amadeo_wi_admin_js', $this->amadeoPluginDirUrl() . '/js/amadeo-widget-image.js');
			wp_localize_script('amadeo_wi_admin_js', 'amadeo_wi_l10n', array(
				'add_images'	=> esc_html__('Add image(s)', 'amadeo-free'),
				'ajax_url'		=> admin_url('admin-ajax.php')
			));
		}
	}
	
	public function form($instance){
		$instance['instanceName']	= str_replace("[instance]", '', $this->get_field_name('instance'));
		$instance['instanceId']		= str_replace("-instance", '', $this->get_field_id('instance'));

		$title	= isset($instance['title'])	? sanitize_text_field($instance['title'])	: '';
		$ids		= isset($instance['ids'])		? sanitize_text_field($instance['ids'])	: '';
		
		$i = 0;
		$idsArray = ($ids) ? json_decode($ids) : array();
?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'amadeo-free'); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
	
		<div id="<?php echo esc_attr($this->get_field_id('container')); ?>" class="amadeo-widget-image ui-sortable">
<?php
			foreach($idsArray as $id):
				${'image_'. $id} = isset($instance['image_'. $id]) ? $instance['image_'. $id] : array();
?>
				<div class="image-preview ui-state-default ui-sortable-handle" data-id="<?php echo $id; ?>">
					<img src="<?php echo ${'image_'. $id}['url']; ?>" alt="<?php echo ${'image_'. $id}['alt']; ?>" />

					<input name="<?php echo esc_attr($this->get_field_name('image_'. $id) .'[url]'); ?>"	value="<?php echo esc_url(${'image_'. $id}['url']); ?>"		class="widefat" type="hidden" />

					<label for="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-alt"><?php esc_html_e('Image alternate text:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($this->get_field_name('image_'. $id) .'[alt]'); ?>"	value="<?php echo esc_attr(${'image_'. $id}['alt']); ?>"		id="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-alt"		class="widefat" />
					
					<label for="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-link"><?php esc_html_e('Link:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($this->get_field_name('image_'. $id) .'[link]'); ?>"	value="<?php echo esc_url(${'image_'. $id}['link']); ?>"		id="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-link"	class="widefat" />
					
					<label for="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-title"><?php esc_html_e('Link title:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($this->get_field_name('image_'. $id) .'[title]'); ?>"	value="<?php echo esc_attr(${'image_'. $id}['title']); ?>"	id="<?php echo esc_attr($this->get_field_id('image_'. $id)); ?>-title"	class="widefat" />

					<button id="<?php echo esc_attr($this->get_field_id('upload-btn')); ?>" type="button" attr-remove-id="<?php echo esc_attr($id); ?>" class="button-secondary remove-btn"><?php esc_html_e('Delete', 'amadeo-free'); ?></button>
				</div>
<?php
				$i++;
			endforeach;
?>
		</div>
		
		<div class="ids-input-container add-btn-container">
			<button id="<?php echo esc_attr($this->get_field_id('upload-btn')); ?>" class="button-secondary media-input"><?php esc_html_e('Add image(s)', 'amadeo-free'); ?></button>
			<input class="ids" type="hidden" id="<?php echo esc_attr($this->get_field_id('ids')); ?>" name="<?php echo esc_attr($this->get_field_name('ids')); ?>" value="<?php echo esc_attr($ids); ?>" />
			<input class="instance-name" type="hidden" value="<?php echo esc_attr($instance['instanceName']); ?>" />
			<input class="instance-id" type="hidden" value="<?php echo esc_attr($instance['instanceId']); ?>" />
		</div>

<?php
	}

	public function widget($args, $instance){
		$title = apply_filters('widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base);
		
		echo $args['before_widget'];
		
		if(!empty($title)){
			echo $args['before_title'] . $title . $args['after_title'];
		}
		
		$ids= isset($instance['ids']) ? sanitize_text_field($instance['ids']) : '';
		
		$idsArray = ($ids) ? json_decode($ids) : array();
		
		foreach($idsArray as $id){
			${'image_'. $id} = isset($instance['image_'. $id]) ? $instance['image_'. $id]	: array();
	?>
			<div class="wcag_widget_image">
	<?php
				if(${'image_'. $id}['link']):
	?>
					<a href="<?php echo esc_url(${'image_'. $id}['link']); ?>" class="center-block" title="<?php echo esc_attr(${'image_'. $id}['title']); ?>" data-toggle="tooltip">
	<?php
				endif;
	?>
					<img src="<?php echo esc_url(${'image_'. $id}['url']); ?>" alt="<?php echo esc_attr(${'image_'. $id}['alt']); ?>" class="center-block" />
	<?php
				if(${'image_'. $id}['link']):
	?>
					</a>
	<?php
				endif;
	?>
			</div>
	<?php
		}
		echo $args['after_widget'];
	}

	public function update($new_instance, $old_instance){
		$instance = $old_instance;
		$instance['title']	= sanitize_text_field($new_instance['title']);
		$instance['ids']		= sanitize_text_field($new_instance['ids']);

		if(current_user_can('unfiltered_html')){
			$idsArray = json_decode($instance['ids']);

			foreach($idsArray as $id){
				foreach($new_instance['image_'. $id] as $key => $value){
					$instance['image_'. $id][$key] = $value;
				}
			}
		}

		return $instance;
	}

	function amadeoImageWidgetAJAX(){
		if(defined('DOING_AJAX') && DOING_AJAX){
			foreach($_REQUEST['instanceData'] as $key => $value){
				${'instance_'. $key} = $value;
			}

			foreach($_REQUEST['imageData'] as $image){
	?>
				<div class="image-preview ui-state-default ui-sortable-handle" data-id="<?php echo $image['id']; ?>">
					<input name="<?php echo esc_attr($instance_name .'[image_'. $image['id'] .']'); ?>[url]"	value="<?php echo esc_url($image['url']); ?>"	class="widefat" type="hidden" />
					
					<img src="<?php echo esc_url($image['url']); ?>" alt="image_<?php echo esc_attr($image['id']); ?>[alt]" />

					<label for="<?php echo esc_attr($instance_id .'-image_'. $image['id']); ?>-alt"><?php esc_html_e('Image alternate text:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($instance_name .'[image_'. $image['id'] .']'); ?>[alt]"		value="<?php echo esc_attr($image['alt']); ?>"		class="widefat"	id="<?php echo esc_attr($instance_id .'-image_'. $image['id']) ?>-alt" />
					
					<label for="<?php echo esc_attr($instance_id .'-image_'. $image['id']); ?>-link"><?php esc_html_e('Link:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($instance_name .'[image_'. $image['id'] .']'); ?>[link]"		value="<?php echo esc_url($image['link']); ?>"		class="widefat"	id="<?php echo esc_attr($instance_id .'-image_'. $image['id']); ?>-link" />
					
					<label for="<?php echo esc_attr($instance_id .'-image_'. $image['id']); ?>-title"><?php esc_html_e('Link title:', 'amadeo-free'); ?></label>
					<input name="<?php echo esc_attr($instance_name .'[image_'. $image['id'] .']'); ?>[title]"	value="<?php echo esc_attr($image['title']); ?>"	class="widefat"	id="<?php echo esc_attr($instance_id .'-image_'. $image['id']); ?>-title" />

					<button class="button-secondary remove-btn" type="button" attr-remove-id="<?php echo esc_attr($image['id']); ?>"><?php esc_html_e('Delete', 'amadeo-free'); ?></button>
				</div>
	<?php
			}
			die();
		}
	}

	function amadeoPluginDirUrl(){
		return strstr(content_url(), 'wp-content', TRUE) . strstr( __DIR__ , 'wp-content'. DIRECTORY_SEPARATOR);
	}
}

add_action('widgets_init',	create_function('', 'return register_widget("AmadeoWidgetImage");'));
